==> alfresco-repository-23.6.0.30-sources.jar: org/alfresco/repo/content/caching/CacheMissException.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.content.caching;

/**
 * CacheMissException will be thrown if an attempt is made to read
 * content from the ContentCache when it is not in the cache.
 * 
 * @author Matt Ward
 */
public class CacheMissException extends RuntimeException
{
    private static final long serialVersionUID = -410818899455752655L; 

    /**
     * @param contentUrl URL of content that was attempted to be retrieved.
     */
    public CacheMissException(String contentUrl)
    {
        super("Content not found in cache [URL=" + contentUrl + "]");
    }
}

==> alfresco-repository-25.3.0.51-sources.jar: org/alfresco/repo/content/caching/CacheMissException.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.content.caching;

/**
 * CacheMissException will be thrown if an attempt is made to read content from the ContentCache when it is not in the cache.
 * 
 * @author Matt Ward
 */
public class CacheMissException extends RuntimeException
{
    private static final long serialVersionUID = -410818899455752655L;

    /**
     * @param contentUrl
     *            URL of content that was attempted to be retrieved.
     */
    public CacheMissException(String contentUrl)
    {
        super("Content not found in cache [URL=" + contentUrl + "]");
    }
}
